package App::IDXUtils;

our $DATE = '2020-12-24'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Command-line utilities related to Indonesian Stock Exchange

__END__

=pod

=encoding UTF-8

=head1 NAME

App::IDXUtils - Command-line utilities related to Indonesian Stock Exchange

=head1 VERSION

This document describes version 0.003 of App::IDXUtils (from Perl distribution App-IDXUtils), released on 2020-12-24.

=head1 SYNOPSIS

=head1 DESCRIPTION

This distribution includes several utilities related to the Indonesian Stock
Exchange (IDX):

=over

=item * L<list-idx-boards>

=item * L<list-idx-brokers>

=item * L<list-idx-firms>

=item * L<list-idx-sectors>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-IDXUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-IDXUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-IDXUtils/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
